Crate minigrep_vielenkz

Crate minigrep_vielenkz 

minigrep

minigrep-vielenkz is a lightweight analogue of grep to find a match in a file

Structs

Config

Functions

run
search
Search for all lines in contents string containing query. Case sensitive.
search_case_insensitive
Search for all lines in contents string containing query. Case insensitive.