minigrep
minigrep-vielenkz is a lightweight analogue of grep to find a match in a file
Structs
Functions
- run
- search
- Search for all lines in contents string containing query. Case sensitive.
- search_
case_ insensitive - Search for all lines in contents string containing query. Case insensitive.